@@ -141,8 +141,6 @@ sub find_elements_by_xpath ( $self, $selector, $cb = undef ) {
 # set_selected
 # toggle
 # is_enabled
-# get_tag_name
-# get_attr
 # get_value
 # is_displayed
 # is_hidden
@@ -169,10 +167,8 @@ sub is_selected ( $self, $cb = undef ) {
     return;
 }
 
-sub get_attr ( $self, $cb = undef ) {
-    ...;
-
-    return;
+sub get_attr ( $self, $attr, $cb = undef ) {
+    return $self->{webdriver}->_send_command( 'GET', "/session/$self->{webdriver}->{session_id}/element/$self->{id}/attribute/$attr", undef, $cb );
 }
 
 sub get_property ( $self, $cb = undef ) {
@@ -192,9 +188,7 @@ sub get_text ( $self, $cb = undef ) {
 }
 
 sub get_tag_name ( $self, $cb = undef ) {
-    ...;
-
-    return;
+    return $self->{webdriver}->_send_command( 'GET', "/session/$self->{webdriver}->{session_id}/element/$self->{id}/name", undef, $cb );
 }
 
 sub get_rect ( $self, $cb = undef ) {
@@ -406,8 +400,8 @@ sub set_attr ( $self, $attr, $val, $cb = undef ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 167, 173, 179, 185,  | ControlStructures::ProhibitYadaOperator - yada operator (...) used                                             |
-## |      | 195, 201, 207        |                                                                                                                |
+## |    3 | 165, 175, 181, 195,  | ControlStructures::ProhibitYadaOperator - yada operator (...) used                                             |
+## |      | 201                  |                                                                                                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
